# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/carousel/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Carousel\\": "packages/litecms/carousel/src",
            "Litecms\\Carousel\\Seeders\\": "packages/litecms/carousel/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Carousel\Providers\CarouselServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Carousel'  => Litecms\Carousel\Facades\Carousel::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Carousel\\Seeders\\CarouselTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Carousel\Providers\CarouselServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Carousel\Providers\CarouselServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Carousel\Providers\CarouselServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/carousel/{modulename}

**User**

    http://path-to-route-folder/user/carousel/{modulename}

**Public**

    http://path-to-route-folder/carousels


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/carousel/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/carousel/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/carousel/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/carousel/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/carousel/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/carousel/{modulename}/{slug}
    METHOD: GET